@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: HsSyck
-version: 0.45
-id: HsSyck-0.45-73a923af2fa8d5a7367e76fa71d86105
+version: 0.50
+id: HsSyck-0.50-7d577f89f428907c2c2137bff0300a26
 
 license: BSD3
 copyright: Audrey Tang, Gaal Yahas, 2005, 2006, 2007, 2008, 2009
@@ -22,21 +22,22 @@ pkgpath: devel/hs-HsSyck
 exposed: True
 exposed-modules: Data.Yaml.Syck
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/HsSyck-0.45
-library-dirs: /usr/local/lib/ghc/HsSyck-0.45
-hs-libraries: HSHsSyck-0.45
+import-dirs: /usr/local/lib/ghc/HsSyck-0.50
+library-dirs: /usr/local/lib/ghc/HsSyck-0.50
+hs-libraries: HSHsSyck-0.50
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.2.0.2-578c91f7479ca9d00c13da2ed514f7ac
-         bytestring-0.9.1.7-41dd05a497806d68d10ffae5438a0632
-         syb-0.1.0.2-0917873f366b0be90a48082271223b4e
+depends: base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
+         bytestring-0.9.1.10-4e62762ee9b2a5d0cc5bc2fbaaeefd53
+         syb-0.3.3-daedbadc9dc041093c4210b3087b5f0b
+         utf8-string-0.3.6-131bec5ed6c825184d560515f17820d3
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-HsSyck-0.45/html/HsSyck.haddock
-haddock-html: /usr/local/share/doc/hs-HsSyck-0.45/html
+haddock-interfaces: /usr/local/share/doc/hs-HsSyck-0.50/html/HsSyck.haddock
+haddock-html: /usr/local/share/doc/hs-HsSyck-0.50/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
